@@ -19,9 +19,9 @@ def render_block(self, block: str, block_type: str, y: int) -> int:
     elif block_type == 'codeblock':
         y = self.render_codeblock(block, block_type, y)
     elif block_type == 'ol':
-        y = self.render_list(block, block_type, y, True)
+        y = self.render_list(block, block_type, y, ordered=True)
     elif block_type == 'ul':
-        y = self.render_list(block, block_type, y, False)
+        y = self.render_list(block, block_type, y, ordered=False)
     elif block_type in ('h1', 'h2', 'h3'):
         y = self.render_text(block, block_type, y)
 
